@@ -5,7 +5,7 @@ import sys
 from io import StringIO
 
 from osaca.frontend import Frontend
-from osaca.parser import ParserAArch64v81, ParserX86ATT
+from osaca.parser import ParserAArch64, ParserX86ATT
 from osaca.semantics import (INSTR_FLAGS, KernelDG, MachineModel,
                              ArchSemantics, reduce_to_section)
 
@@ -29,7 +29,7 @@ class KerncraftAPI(object):
         self.semantics = ArchSemantics(self.machine_model)
         isa = self.machine_model.get_ISA().lower()
         if isa == 'aarch64':
-            self.parser = ParserAArch64v81()
+            self.parser = ParserAArch64()
         elif isa == 'x86':
             self.parser = ParserX86ATT()
 
@@ -40,9 +40,7 @@ class KerncraftAPI(object):
     def create_output(self, verbose=False):
         kernel_graph = KernelDG(self.kernel, self.parser, self.machine_model)
         frontend = Frontend(arch=self.machine_model.get_arch())
-        with Capturing() as output:
-            frontend.print_full_analysis(self.kernel, kernel_graph, verbose=verbose)
-        return '\n'.join(output)
+        return frontend.full_analysis(self.kernel, kernel_graph, verbose=verbose)
 
     def get_unmatched_instruction_ratio(self):
         unmatched_counter = 0
