@@ -123,10 +123,12 @@ class ParserAArch64(BaseParser):
         vector = (
             pp.oneOf('v z', caseless=True).setResultsName('prefix')
             + pp.Word(pp.nums).setResultsName('name')
-            + pp.Literal('.')
-            + pp.Optional(pp.Word('12468')).setResultsName('lanes')
-            + pp.Word(pp.alphas, exact=1).setResultsName('shape')
-            + pp.Optional(index)
+            + pp.Optional(
+                pp.Literal('.')
+                + pp.Optional(pp.Word('12468')).setResultsName('lanes')
+                + pp.Word(pp.alphas, exact=1).setResultsName('shape')
+                + pp.Optional(index)
+            )
         )
         predicate = (
             pp.CaselessLiteral('p').setResultsName('prefix')
@@ -202,6 +204,8 @@ class ParserAArch64(BaseParser):
             + pp.Optional(operand_rest.setResultsName('operand3'))
             + pp.Optional(pp.Suppress(pp.Literal(',')))
             + pp.Optional(operand_rest.setResultsName('operand4'))
+            + pp.Optional(pp.Suppress(pp.Literal(',')))
+            + pp.Optional(operand_rest.setResultsName('operand5'))
             + pp.Optional(self.comment)
         )
 
@@ -320,6 +324,9 @@ class ParserAArch64(BaseParser):
         # Check fourth operand
         if 'operand4' in result:
             operands.append(self.process_operand(result['operand4']))
+        # Check fifth operand
+        if 'operand5' in result:
+            operands.append(self.process_operand(result['operand5']))
 
         return_dict = AttrDict(
             {
