@@ -38,14 +38,18 @@ class ParserX86ATT(BaseParser):
         rest = pp.Word(pp.alphanums + '$_.+-')
         identifier = pp.Group(
             pp.Optional(id_offset).setResultsName('offset')
-            + pp.Combine(first + pp.Optional(rest)).setResultsName('name')
+            + pp.Combine(pp.delimitedList(
+                pp.Combine(first + pp.Optional(rest)), delim='::'), joinString='::'
+            ).setResultsName('name')
             + pp.Optional(relocation).setResultsName('relocation')
         ).setResultsName('identifier')
         # Label
-        rest = pp.Word(pp.alphanums + '$_.+-()')
+        label_rest = pp.Word(pp.alphanums + '$_.+-()')
         label_identifier = pp.Group(
             pp.Optional(id_offset).setResultsName('offset')
-            + pp.Combine(first + pp.Optional(rest)).setResultsName('name')
+            + pp.Combine(pp.delimitedList(
+                pp.Combine(first + pp.Optional(label_rest)), delim='::'), joinString='::'
+            ).setResultsName('name')
             + pp.Optional(relocation).setResultsName('relocation')
         ).setResultsName('identifier')
         numeric_identifier = pp.Group(
@@ -106,6 +110,10 @@ class ParserX86ATT(BaseParser):
             + segment_extension.setResultsName(self.SEGMENT_EXT_ID)
         )
         # Memory: offset | seg:seg_ext | offset(base, index, scale){mask}
+        memory_abs = (
+            pp.Suppress(pp.Literal('*'))
+            + (offset | self.register).setResultsName('offset')
+        )
         memory = pp.Group(
             (
                 pp.Optional(pp.Suppress(pp.Literal('*')))
@@ -124,6 +132,7 @@ class ParserX86ATT(BaseParser):
                     + pp.Literal('}')
                 )
             )
+            | memory_abs
             | memory_segmentation
             | (hex_number | pp.Word(pp.nums)).setResultsName('offset')
         ).setResultsName(self.MEMORY_ID)
